SWDEV-465162 - Support ignored error

Modified
TestContext::finalizeResults()

Added
HIP_CHECK_IGNORED_RETURN()
HIP_CHECK_ERRORS()

to supported ignored error such as hipErrorNotSupported.

Enable all mipmap tests in catch2 memory folder for linux.
The issues in the following tickets should be fixed.
SWDEV-465162, SWDEV-465163, SWDEV-465165, SWDEV-465166,
SWDEV-465168, SWDEV-465171, SWDEV-465172

Change-Id: I1146d6184582a7111a5af25b52f9e12c6a160e49


[ROCm/hip-tests commit: de9581efb6]
Tá an tiomantas seo le fáil i:
taosang2
2024-06-11 14:09:37 -04:00
tiomanta ag Rakesh Roy
tuismitheoir 402fffac2b
tiomantas b3d203d19b
D'athraigh 5 comhad le 54 breiseanna agus 41 scriosta
@@ -52,7 +52,8 @@ TEMPLATE_TEST_CASE("Unit_hipFreeMipmappedArrayImplicitSyncArray", "", char, floa
const unsigned int numLevels = GENERATE(1, 5, 7);
HIP_CHECK(hipMallocMipmappedArray(&arrayPtr, &desc, extent, numLevels, flags));
HIP_CHECK_IGNORED_RETURN(hipMallocMipmappedArray(&arrayPtr, &desc, extent, numLevels, flags),
hipErrorNotSupported);
LaunchDelayKernel(std::chrono::milliseconds{50}, nullptr);
// make sure device is busy
@@ -82,7 +83,8 @@ TEST_CASE("Unit_hipFreeMipmappedArray_Negative_DoubleFree") {
const unsigned int numLevels = GENERATE(1, 5, 7);
HIP_CHECK(hipMallocMipmappedArray(&arrayPtr, &desc, extent, numLevels, flags));
HIP_CHECK_IGNORED_RETURN(hipMallocMipmappedArray(&arrayPtr, &desc, extent, numLevels, flags),
hipErrorNotSupported);
HIP_CHECK(hipFreeMipmappedArray(arrayPtr));
HIP_CHECK_ERROR(hipFreeMipmappedArray(arrayPtr), hipErrorContextIsDestroyed);